@@ -15,19 +15,16 @@ class Preprocessing(Enum):
     SIMPLE = auto()
 
 
-def load_and_preprocess_image(
-        image_path: str,
+def preprocess_image(
+        pil_image: Image,
         preprocessing: Preprocessing = Preprocessing.YAHOO
 ) -> np.ndarray:
     """
-    Load image from image_path with preprocessing for the
-    pre-trained Open NSFW model weights.
+    Preprocessing for the pre-trained Open NSFW model weights.
 
     References:
     https://github.com/mdietrichstein/tensorflow-open_nsfw
     """
-    pil_image = Image.open(image_path)
-
     if pil_image.mode != "RGB":
         pil_image = pil_image.convert("RGB")
 
@@ -40,11 +37,11 @@ def load_and_preprocess_image(
 
         image = skimage.io.imread(fh_im, as_gray=False).astype(np.float32)
 
-        H, W, _ = image.shape
+        height, width, _ = image.shape
         h, w = (224, 224)
 
-        h_off = max((H - h) // 2, 0)
-        w_off = max((W - w) // 2, 0)
+        h_off = max((height - h) // 2, 0)
+        w_off = max((width - w) // 2, 0)
         image = image[h_off:h_off + h, w_off:w_off + w, :]
 
     elif preprocessing == Preprocessing.SIMPLE:
