@@ -10,17 +10,51 @@ from PIL import Image  # type: ignore
 
 from ._download import get_default_weights_path
 from ._image import preprocess_image, Preprocessing
+from ._inspection import make_and_save_nsfw_grad_cam
 from ._model import make_open_nsfw_model
 
 
+def predict_image(
+        image_path: str,
+        preprocessing: Preprocessing = Preprocessing.YAHOO,
+        weights_path: Optional[str] = get_default_weights_path(),
+        grad_cam_path: Optional[str] = None,
+        grad_cam_height: int = 512,
+        grad_cam_width: int = 512,
+        alpha: float = 0.5
+) -> float:
+    """
+    Pipeline from single image path to predicted NSFW probability.
+    Optionally generate and save the Grad-CAM plot.
+    """
+    image = preprocess_image(Image.open(image_path), preprocessing)
+    model = make_open_nsfw_model(weights_path=weights_path)
+    nsfw_probability = float(
+        model.predict(np.expand_dims(image, 0), batch_size=1)[0][1]
+    )
+
+    if grad_cam_path is not None:
+        make_and_save_nsfw_grad_cam(
+            image, model, grad_cam_path,
+            grad_cam_height, grad_cam_width, alpha
+        )
+
+    return nsfw_probability
+
+
 def predict_images(
         image_paths: Sequence[str],
         batch_size: int = 16,
         preprocessing: Preprocessing = Preprocessing.YAHOO,
-        weights_path: Optional[str] = get_default_weights_path()
+        weights_path: Optional[str] = get_default_weights_path(),
+        grad_cam_paths: Optional[Sequence[str]] = None,
+        grad_cam_height: int = 512,
+        grad_cam_width: int = 512,
+        alpha: float = 0.5
 ) -> List[float]:
     """
     Pipeline from image paths to predicted NSFW probabilities.
+    Optionally generate and save the Grad-CAM plots.
     """
     images = np.array([
         preprocess_image(Image.open(image_path), preprocessing)
@@ -29,25 +63,17 @@ def predict_images(
     model = make_open_nsfw_model(weights_path=weights_path)
     predictions = model.predict(images, batch_size=batch_size)
     nsfw_probabilities: List[float] = predictions[:, 1].tolist()
+
+    if grad_cam_paths is not None:
+        for image, grad_cam_path in zip(images, grad_cam_paths):
+            make_and_save_nsfw_grad_cam(
+                image, model, grad_cam_path,
+                grad_cam_height, grad_cam_width, alpha
+            )
+
     return nsfw_probabilities
 
 
-def predict_image(
-        image_path: str,
-        preprocessing: Preprocessing = Preprocessing.YAHOO,
-        weights_path: Optional[str] = get_default_weights_path()
-) -> float:
-    """
-    Pipeline from single image path to predicted NSFW probability.
-    """
-    return predict_images(
-        [image_path],
-        batch_size=1,
-        preprocessing=preprocessing,
-        weights_path=weights_path
-    )[0]
-
-
 def predict_video_frames(
         video_path: str,
         frame_interval: int = 8,
